from cms.plugin_pool import plugin_pool
from cms.plugin_base import CMSPluginBase
from django.utils.translation import ugettext_lazy as _
from models import WidgetConfig
from conf.settings import INTEGRATION_ID, BASKET_ID


class OpenSystemPlugin(CMSPluginBase):
    model = WidgetConfig
    name = _("OpenSystem widget")
    render_template = "djangocms_opensystem/widget.html"

    def render(self, context, instance, placeholder):
        context.update({
            "object": instance,
            "BASKET_ID": BASKET_ID,
            "INTEGRATION_ID": INTEGRATION_ID,
            "placeholder": placeholder,
        })
        return context

plugin_pool.register_plugin(OpenSystemPlugin)



# Third party
from django.conf import settings
from django.core.exceptions import ImproperlyConfigured


# django.utils.translation should never be imported from within a settings file!
# Instead use a fake _() function in order to mark the strings wrapped with _() for translation.
_ = lambda s: s  # noqa

BASKET_ID = getattr(settings, "DJANGOCMS_OPENSYSTEM_BASKET_ID", None)
if BASKET_ID is None:
    raise ImproperlyConfigured("DJANGOCMS_OPENSYSTEM_BASKET_ID must be defined")

INTEGRATION_ID = getattr(settings, "DJANGOCMS_OPENSYSTEM_INTEGRATION_ID", None)
if INTEGRATION_ID is None:
    raise ImproperlyConfigured("DJANGOCMS_OPENSYSTEM_INTEGRATION_ID must be defined")



from django.db import models
from django.utils.translation import ugettext_lazy as _
from cms.models import CMSPlugin


class WidgetConfig(CMSPlugin):
    reference = models.CharField(_("Reference"), max_length=255, help_text=_("OpenSystem reference (e.g.: CVERT-90333)"))

    def __unicode__(self):
        return self.reference
